﻿using iFileProxy.Attributes;
using iFileProxy.Helpers;
using iFileProxy.Interfaces;
using iFileProxy.Services;
using System.Reflection;

namespace iFileProxy.Handlers.CommandLine
{
    [CommandLineArgument(FullArgumentName ="--help",ShortArgumentName = "-h", Description = "显示帮助文本")]
    public class HelpHandler : ICommandLineHandler
    {
        string[] _args = [];
        public HelpHandler(string[] args) { 
            _args = args;
        }

        public void Process()
        {
            Dictionary<string,string> helpText = CommandLineArgumentDispatcher.GetHelpTextDict();
            // 找到最长的键长度
            int maxKeyLength = helpText.Keys.Max(key => key.Length);

            // 打印表头
            Console.WriteLine("参数: ");

            // 打印每一行的帮助信息，确保对齐
            foreach (var ht in helpText)
            {
                Console.WriteLine($"    {ht.Key}{new string(' ', maxKeyLength - ht.Key.Length)}\t{ht.Value}");
            }
            Console.WriteLine();

            Console.WriteLine("示例: ");

            Console.WriteLine($"    --cors-allowed-domains=https://www.example.com;http://api.example.com:4433");
            Console.WriteLine($"    -B=http://0.0.0.0:5000");


            Console.WriteLine(new string('\n',2));

            Console.WriteLine($"程序编译日期(UTC+8): {MasterHelper.GetBuildTime(Assembly.GetExecutingAssembly())}");

            Console.WriteLine();
            Environment.Exit(0 );
        }
    }
}
