﻿using iFileProxy.Attributes;
using iFileProxy.Config;
using iFileProxy.Helpers;
using iFileProxy.Interfaces;
using Serilog;
using System.Reflection;

namespace iFileProxy.Handlers
{
    /// <summary>
    /// 命令行参数调度器
    /// </summary>
    public class CommandLineArgumentDispatcher
    {
        private readonly static Serilog.ILogger _logger = Log.Logger.ForContext<CommandLineArgumentDispatcher>();

        // 获取当前执行的程序集
        static Assembly assembly = Assembly.GetExecutingAssembly();

        // 获取程序集中所有的类型
        static Type[] types = [];

        public CommandLineArgumentDispatcher()
        {
            LoadAssemblyData();
        }

        static void LoadAssemblyData()
        {
            assembly = Assembly.GetExecutingAssembly();
            types = assembly.GetTypes();
        }


        public static void Parse(string[] args)
        {
            LoadAssemblyData();
            // 遍历所有类型，查找带有 CommandLineArgumentAttribute 的类
            foreach (Type type in types)
            {
                // 检查类型是否具有 CommandLineArgumentAttribute
                var attribute = type.GetCustomAttribute<CommandLineArgumentAttribute>();
                if (attribute != null && (args.Contains(attribute.FullArgumentName) || args.Contains(attribute.ShortArgumentName)))
                {
                    var commandLineHandler = (ICommandLineHandler?)Activator.CreateInstance(type, [args]);
                    commandLineHandler?.Process();
                }
            }
        }

        public static Dictionary<string, string> GetHelpTextDict()
        {
            static string GetHelpText(CommandLineArgumentAttribute attribute)
            {
                if (attribute.NeedValue && attribute.FullArgumentName.Trim() == string.Empty) // 需要值且没有长参数
                {
                    return $"{attribute.ShortArgumentName}=<value>";
                }
                else if (attribute.NeedValue && attribute.ShortArgumentName.Trim() == string.Empty)// 需要值且没有短参数
                {
                    return $"{attribute.ShortArgumentName} {attribute.FullArgumentName}=<value>";
                }
                else if (attribute.NeedValue && attribute.FullArgumentName.Trim() != "" && attribute.ShortArgumentName.Trim() != "") // 都需要
                {
                    return $"{attribute.ShortArgumentName}=<value>，{attribute.FullArgumentName}=<value>";
                }
                else if (attribute.FullArgumentName.Trim() == "" && attribute.ShortArgumentName.Trim() == "") // 都没有
                {
                    throw new ArgumentException("该参数长短参数名均为空 请联系软件开发者反馈");
                }
                else if (!attribute.NeedValue && attribute.FullArgumentName.Trim() == string.Empty) // 只有短参且不需要值
                    return attribute.ShortArgumentName ;
                else if (!attribute.NeedValue && attribute.ShortArgumentName.Trim() == string.Empty)// 只有长参且不需要值
                    return $"{attribute.ShortArgumentName} {attribute.FullArgumentName}";
                else
                    return $"{attribute.ShortArgumentName}，{attribute.FullArgumentName}";
            }
            Dictionary<string, string> r = [];
            foreach (var handler in types)
            {
                var h = handler.GetCustomAttribute<CommandLineArgumentAttribute>();
                if (h != null)
                {
                        r.Add(GetHelpText(h), h.Description);
                }
            }
            return r;
        }
    }
}
